lcvtoolbox.core.schemas.CvatApiTaskDetailsDict
==============================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: CvatApiTaskDetailsDict
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiTaskDetailsDict.__init__
      ~CvatApiTaskDetailsDict.clear
      ~CvatApiTaskDetailsDict.copy
      ~CvatApiTaskDetailsDict.fromkeys
      ~CvatApiTaskDetailsDict.get
      ~CvatApiTaskDetailsDict.items
      ~CvatApiTaskDetailsDict.keys
      ~CvatApiTaskDetailsDict.pop
      ~CvatApiTaskDetailsDict.popitem
      ~CvatApiTaskDetailsDict.setdefault
      ~CvatApiTaskDetailsDict.update
      ~CvatApiTaskDetailsDict.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiTaskDetailsDict.id
      ~CvatApiTaskDetailsDict.name
      ~CvatApiTaskDetailsDict.project_id
      ~CvatApiTaskDetailsDict.mode
      ~CvatApiTaskDetailsDict.owner
      ~CvatApiTaskDetailsDict.assignee
      ~CvatApiTaskDetailsDict.bug_tracker
      ~CvatApiTaskDetailsDict.created_date
      ~CvatApiTaskDetailsDict.updated_date
      ~CvatApiTaskDetailsDict.overlap
      ~CvatApiTaskDetailsDict.segment_size
      ~CvatApiTaskDetailsDict.status
      ~CvatApiTaskDetailsDict.labels
      ~CvatApiTaskDetailsDict.segments
      ~CvatApiTaskDetailsDict.dimension
      ~CvatApiTaskDetailsDict.data_compressed_chunk_type
      ~CvatApiTaskDetailsDict.data_original_chunk_type
      ~CvatApiTaskDetailsDict.image_quality
      ~CvatApiTaskDetailsDict.data
      ~CvatApiTaskDetailsDict.subset
      ~CvatApiTaskDetailsDict.organization
      ~CvatApiTaskDetailsDict.target_storage
      ~CvatApiTaskDetailsDict.source_storage
      ~CvatApiTaskDetailsDict.jobs
   
   